"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.clearFolders = clearFolders;
exports.addDefaultIndex = addDefaultIndex;
var rimraf_1 = require("rimraf");
var fs_1 = __importDefault(require("fs"));
var path_1 = __importDefault(require("path"));
var log_1 = require("./log");
var websocketServer_1 = require("./websocketServer");
var webDevServer_1 = require("./webDevServer");
function clearFolders() {
    var folders = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        folders[_i] = arguments[_i];
    }
    folders.forEach(function (folder) {
        (0, log_1.log)("RM_FOLDER", folder);
        (0, rimraf_1.rimrafSync)(folder);
    });
}
/**
 * adds index file with use template
 * user template need to have $bundle tag in header, so we can inject code
 * @param config
 */
function addDefaultIndex(config) {
    // make folder if it does not exist
    fs_1.default.mkdirSync(config.distFolder, { recursive: true });
    // if hbr then add start websocket server
    if (config.hbr) {
        (0, websocketServer_1.startWebsocketServer)(config.webSocketPort || 8081);
    }
    var normalBundle = "<script>import(\"".concat(config.entry, "\")</script>");
    var hbrBundle = "\n    <script>\n      let version = 0;\n      import(\"".concat(config.entry, "?v=\" + version);\n      let connected = false;\n\n      const websocketConnection = function () {\n        const ws = new WebSocket(\"ws://").concat(config.host || "localhost", ":").concat(config.webSocketPort || 8081, "\");\n\n        ws.addEventListener(\"open\", function () {\n          connected = true;\n          ws.send(\"connect\");\n        });\n\n        ws.addEventListener(\"close\", function () {\n          connected = false;\n          console.log(\"connection lost\");\n          websocketConnection();\n        });\n\n        ws.addEventListener(\"message\", function (event) {\n          ").concat(config.userInjectOnHbr && config.hbr ? config.userInjectOnHbr : "", "\n          \n          version++;\n          import(\"").concat(config.entry, "?v=\" + version);\n        });\n\n\n      };\n      websocketConnection();\n    </script>");
    if (config.indexTemplate) {
        fs_1.default.writeFileSync(path_1.default.resolve(config.distFolder, "index.html"), config.indexTemplate.replace("$bundle", config.hbr ? hbrBundle : normalBundle));
        (0, log_1.log)("ADD INDEX", "added");
    }
    if (config.devServer) {
        (0, webDevServer_1.startDevServer)(config.devServerPort || 8080, config.distFolder, config.publicFolders, config.host || "localhost");
        if (config.devServerStart) {
            var url = "http://".concat(config.host || "localhost", ":") +
                (config.devServerPort || 8080) +
                (config.devServerPath || "");
            var start = process.platform == "darwin"
                ? "open"
                : process.platform == "win32"
                    ? "start"
                    : "xdg-open";
            require("child_process").exec(start + " " + url);
        }
    }
}
//# sourceMappingURL=addIndex.js.map