"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TypeChecker = exports.TypeHelperClass = void 0;
var child = __importStar(require("child_process"));
var path = __importStar(require("path"));
var interfaces_1 = require("./interfaces");
require("./register.json");
var getPath_1 = require("./getPath");
var inspectCode_1 = require("./inspectCode");
var printResult_1 = require("./printResult");
var printSettings_1 = require("./printSettings");
var logger_1 = require("./logger");
var TypeHelperClass = /** @class */ (function () {
    function TypeHelperClass(options) {
        this.options = options;
        // get/set base path
        if (!this.options) {
            this.options = {};
        }
        this.options.basePathSetup = options.basePath; // save original path
        this.options.basePath = options.basePath
            ? path.resolve(process.cwd(), options.basePath)
            : process.cwd();
        // get name
        this.options.name = this.options.name ? this.options.name : '';
        // shorten filenames to de-clutter output?
        this.options.shortenFilenames = this.options.shortenFilenames === false ? false : true;
        // get tsconfig path and options
        if (options.tsConfig) {
            var tsconf = (0, getPath_1.getPath)(options.tsConfig, options);
            this.options.tsConfigJsonContent = require(tsconf);
        }
        else {
            // no settings, using default
            if (!this.options.tsConfigJsonContent) {
                this.options.tsConfigJsonContent = {
                    compilerOptions: {}
                };
            }
        }
        if (options.tsConfigOverride) {
            var oldConfig = this.options.tsConfigJsonContent;
            for (var att in options.tsConfigOverride) {
                if (att === 'compilerOptions') {
                    if (oldConfig.compilerOptions) {
                        for (var attCom in options.tsConfigOverride.compilerOptions) {
                            if (attCom) {
                                oldConfig.compilerOptions[attCom] = (options.tsConfigOverride).compilerOptions[attCom];
                            }
                        }
                    }
                    else {
                        oldConfig.compilerOptions = options.tsConfigOverride.compilerOptions;
                    }
                }
                else {
                    oldConfig[att] = options.tsConfigOverride[att];
                }
            }
        }
    }
    TypeHelperClass.prototype.printSettings = function () {
        (0, printSettings_1.printSettings)(this.options);
    };
    TypeHelperClass.prototype.inspectAndPrint = function () {
        var lastResult = (0, inspectCode_1.inspectCode)(this.options);
        return (0, printResult_1.printResult)(this.options, lastResult);
    };
    TypeHelperClass.prototype.inspectOnly = function (oldProgram) {
        return (0, inspectCode_1.inspectCode)(this.options, oldProgram);
    };
    TypeHelperClass.prototype.printOnly = function (errors) {
        if (!errors || (errors && !errors.oldProgram)) {
            logger_1.Logger.info(logger_1.C_BgYellow, logger_1.C_Black, "WARNING  ".concat(logger_1.C_Reset + logger_1.C_Yellow, " No old program in params, auto running inspect first"), logger_1.C_Reset);
            return this.inspectAndPrint();
        }
        else {
            return (0, printResult_1.printResult)(this.options, errors);
        }
    };
    TypeHelperClass.prototype.worker_watch = function (pathToWatch) {
        this.startWorker();
        this.worker.send({
            quit: false,
            type: interfaces_1.WorkerCommand.watch,
            pathToWatch: pathToWatch,
            options: this.options
        });
    };
    TypeHelperClass.prototype.worker_kill = function () {
        if (this.worker) {
            this.worker.kill();
        }
    };
    TypeHelperClass.prototype.worker_inspect = function () {
        if (!this.worker) {
            this.startWorker();
        }
        this.worker.send({ type: interfaces_1.WorkerCommand.inspectCode, options: this.options });
    };
    TypeHelperClass.prototype.worker_PrintSettings = function () {
        if (!this.worker) {
            this.startWorker();
        }
        this.worker.send({ type: interfaces_1.WorkerCommand.printSettings, options: this.options });
    };
    TypeHelperClass.prototype.worker_print = function () {
        if (!this.worker) {
            logger_1.Logger.info(logger_1.C_BgYellow, "WARNING  ".concat(logger_1.C_Reset + logger_1.C_Yellow, "Need to inspect code before printing first"), logger_1.C_Reset);
        }
        else {
            this.worker.send({ type: interfaces_1.WorkerCommand.printResult, options: this.options });
        }
    };
    TypeHelperClass.prototype.worker_inspectAndPrint = function () {
        if (!this.worker) {
            this.startWorker();
        }
        this.worker.send({ type: interfaces_1.WorkerCommand.inspectCodeAndPrint, options: this.options });
    };
    TypeHelperClass.prototype.startWorker = function () {
        var _this = this;
        // create worker fork
        this.worker = child.fork(path.join(__dirname, 'worker'), []);
        // listen for worker messages
        this.worker.on('message', function (msg) {
            if (msg === 'error') {
                // if error then exit
                logger_1.Logger.info(logger_1.C_BgYellow, "WARNING  ".concat(logger_1.C_Reset + logger_1.C_Yellow, "- error typechecker"), logger_1.C_Reset);
                process.exit(1);
            }
            else {
                // if not error, then just kill worker
                logger_1.Logger.info(logger_1.C_BgYellow, "WARNING  ".concat(logger_1.C_Reset + logger_1.C_Yellow, " Typechecker(").concat(_this.options.name, ") killing worker"), logger_1.C_Reset);
                _this.worker_kill();
            }
        });
    };
    return TypeHelperClass;
}());
exports.TypeHelperClass = TypeHelperClass;
var TypeChecker = function (options) {
    return new TypeHelperClass(options);
};
exports.TypeChecker = TypeChecker;
//# sourceMappingURL=index.js.map