"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.printResult = printResult;
var interfaces_1 = require("./interfaces");
var path = __importStar(require("path"));
var processTsDiagnostics_1 = require("./processTsDiagnostics");
var logger_1 = require("./logger");
function printResult(options, errors) {
    // get the lint errors messages
    var tsErrorMessages = (0, processTsDiagnostics_1.processTsDiagnostics)(options, errors);
    // group by filename
    var groupedErrors = {};
    tsErrorMessages.forEach(function (error) {
        if (!groupedErrors[error.fileName]) {
            groupedErrors[error.fileName] = [];
        }
        groupedErrors[error.fileName].push(error);
    });
    // get errors totals
    var optionsErrors = errors.optionsErrors.length;
    var globalErrors = errors.globalErrors.length;
    var syntacticErrors = errors.syntacticErrors.length;
    var semanticErrors = errors.semanticErrors.length;
    var totalsErrors = optionsErrors + globalErrors + syntacticErrors + semanticErrors;
    var allErrors = Object.entries(groupedErrors).map(function (_a) {
        var fileName = _a[0], errors = _a[1];
        var short = options.shortenFilenames !== false ? true : false;
        var fullFileName = path.resolve(fileName);
        var shortFileName = fullFileName.split(options.basePath).join('.');
        if (path.isAbsolute(shortFileName)) {
            // most likely a tsconfig path
            shortFileName = path.relative(process.cwd(), fullFileName);
        }
        else {
            // if somepne passes in basepath we need to use that in print
            if (options.basePathSetup) {
                shortFileName = path.join(options.basePathSetup, shortFileName);
            }
        }
        return ("\n   ".concat(logger_1.C_Reset + logger_1.C_Blue + logger_1.C_Underline + shortFileName + logger_1.C_Reset + logger_1.C_Gray, " - ").concat(errors.length, " errors.").concat(logger_1.C_Reset, "\n") +
            errors
                .map(function (err) {
                var fName = short ? shortFileName : fullFileName;
                var text = "".concat(logger_1.C_Yellow, "    -  ").concat(fName, ":").concat(err.line, ":").concat(err.char).concat(logger_1.C_Reset).concat(logger_1.C_Dim, " (").concat(err.category, " ").concat(err.code, ") ").concat(err.message).concat(logger_1.C_Reset);
                return text;
            })
                .join(interfaces_1.END_LINE));
    });
    var name = options.name;
    // print if any
    if (allErrors.length > 0) {
        // insert header
        logger_1.Logger.info(logger_1.C_Reset, "".concat(logger_1.C_NewLine + logger_1.C_White + logger_1.C_BgRed, " ERROR ").concat(logger_1.C_Reset, " Typechecker inspection - (").concat(name ? name : 'no-name', "):"), "".concat(logger_1.C_Gray).concat(totalsErrors, " errors.").concat(logger_1.C_Reset));
        logger_1.Logger.info(allErrors.join(interfaces_1.END_LINE));
    }
    else {
        logger_1.Logger.info(logger_1.C_NewLine, logger_1.C_BgGreen, "SUCCESS ", logger_1.C_Reset, logger_1.C_Green, "Typechecker inspection - (".concat(name ? name : 'no-name', "):"), "No Errors found", logger_1.C_Reset, logger_1.C_NewLine);
    }
    // print option errors
    if (errors.optionsErrors.length) {
        logger_1.Logger.info(logger_1.C_NewLine, "".concat(logger_1.C_Underline, "Option errors:"), logger_1.C_Reset, "".concat(errors.optionsErrors.length, " errors."));
        var optionErrorsText = Object.entries(errors.optionsErrors).map(function (_a) {
            var no = _a[0], err = _a[1];
            var messageText = err.messageText;
            if (typeof messageText === 'object' && messageText !== null) {
                messageText = JSON.stringify(messageText);
            }
            var text = "".concat(logger_1.C_Yellow, "   -  tsConfig: (").concat(err.category, ":").concat(err.code, ")").concat(logger_1.C_Gray, " ").concat(messageText).concat(logger_1.C_Reset);
            return text;
        });
        logger_1.Logger.info(optionErrorsText.join('\n'));
    }
    // todo: this needs testing, how do I create a global error??
    try {
        if (errors.globalErrors.length) {
            logger_1.Logger.info("\n", logger_1.C_Underline + logger_1.C_Red, "Option errors:", logger_1.C_Gray, "".concat(errors.globalErrors.length, " errors"), logger_1.C_Reset);
            var globalErrorsText = Object.entries(errors.globalErrors).map(function (_a) {
                var no = _a[0], err = _a[1];
                var messageText = err.messageText;
                if (typeof messageText === 'object' && messageText !== null) {
                    messageText = JSON.stringify(messageText);
                }
                return "".concat(logger_1.C_Yellow, "  -  tsConfig: (").concat(err.category, ":").concat(err.code, ")").concat(logger_1.C_Gray, " ").concat(messageText).concat(logger_1.C_Reset);
            });
            logger_1.Logger.info(globalErrorsText.join('\n'));
        }
    }
    catch (err) {
        console.log("Global error", err);
    }
    // if errors, show user
    if (options.print_summary) {
        if (totalsErrors) {
            // write header
            logger_1.Logger.info('\n', "".concat(logger_1.C_Underline, "Error Summary:").concat(logger_1.C_Reset), "".concat(logger_1.C_Gray, "- ").concat(totalsErrors, " errors.").concat(logger_1.C_Reset));
            logger_1.Logger.info("".concat(logger_1.C_Reset).concat(optionsErrors ? logger_1.C_Red : logger_1.C_Dim, "   - Options: ").concat(optionsErrors, "\n"), "".concat(logger_1.C_Reset).concat(semanticErrors ? logger_1.C_Red : logger_1.C_Dim, "  - Options: ").concat(semanticErrors, "\n"), "".concat(logger_1.C_Reset).concat(syntacticErrors ? logger_1.C_Red : logger_1.C_Dim, "  - Options: ").concat(syntacticErrors, "\n"), "".concat(logger_1.C_Reset).concat(globalErrors ? logger_1.C_Red : logger_1.C_Dim, "  - Options: ").concat(globalErrors, "\n"));
        }
    }
    if (options.print_runtime) {
        logger_1.Logger.info("".concat(logger_1.C_Gray, "Typechecker inspection time:"), "".concat(errors.elapsedInspectionTime, "ms").concat(logger_1.C_Reset));
    }
    return totalsErrors;
}
//# sourceMappingURL=printResult.js.map